summaryrefslogtreecommitdiffstats
path: root/kresources/scalix/shared
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/scalix/shared')
-rw-r--r--kresources/scalix/shared/kmailconnection.cpp10
-rw-r--r--kresources/scalix/shared/kmailconnection.h7
-rw-r--r--kresources/scalix/shared/resourcescalixbase.cpp10
-rw-r--r--kresources/scalix/shared/resourcescalixbase.h6
-rw-r--r--kresources/scalix/shared/scalixbase.cpp38
-rw-r--r--kresources/scalix/shared/scalixbase.h24
-rw-r--r--kresources/scalix/shared/subresource.cpp6
-rw-r--r--kresources/scalix/shared/subresource.h10
8 files changed, 56 insertions, 55 deletions
diff --git a/kresources/scalix/shared/kmailconnection.cpp b/kresources/scalix/shared/kmailconnection.cpp
index 60ea25ee..5a157048 100644
--- a/kresources/scalix/shared/kmailconnection.cpp
+++ b/kresources/scalix/shared/kmailconnection.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -75,8 +75,8 @@ bool KMailConnection::connectToKMail()
TQString error;
TQCString dcopService;
int result = KDCOPServiceStarter::self()->
- findServiceFor( "DCOP/ResourceBackend/IMAP", TQString::null,
- TQString::null, &error, &dcopService );
+ findServiceFor( "DCOP/ResourceBackend/IMAP", TQString(),
+ TQString(), &error, &dcopService );
if ( result != 0 ) {
kdError(5650) << "Couldn't connect to the IMAP resource backend\n";
// TODO: You might want to show "error" (if not empty) here,
diff --git a/kresources/scalix/shared/kmailconnection.h b/kresources/scalix/shared/kmailconnection.h
index 3d34d5c6..6eab8ff1 100644
--- a/kresources/scalix/shared/kmailconnection.h
+++ b/kresources/scalix/shared/kmailconnection.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -49,6 +49,7 @@ class ResourceScalixBase;
*/
class KMailConnection : public TQObject, public DCOPObject {
Q_OBJECT
+// TQ_OBJECT
K_DCOP
// These are the methods called by KMail when the resource changes
diff --git a/kresources/scalix/shared/resourcescalixbase.cpp b/kresources/scalix/shared/resourcescalixbase.cpp
index 9bd0afb8..c9c7ee11 100644
--- a/kresources/scalix/shared/resourcescalixbase.cpp
+++ b/kresources/scalix/shared/resourcescalixbase.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -155,7 +155,7 @@ TQString ResourceScalixBase::findWritableResource( const ResourceMap& resources
if ( possible.isEmpty() ) { // None found!!
kdWarning(5650) << "No writable resource found!" << endl;
KMessageBox::error( 0, i18n( "No writable resource was found, saving will not be possible. Reconfigure KMail first." ) );
- return TQString::null;
+ return TQString();
}
if ( possible.count() == 1 )
// Just one found
@@ -167,7 +167,7 @@ TQString ResourceScalixBase::findWritableResource( const ResourceMap& resources
"Please select the one you want to write to." ),
possible.keys() );
if ( chosenLabel.isEmpty() ) // cancelled
- return TQString::null;
+ return TQString();
return possible[chosenLabel];
}
diff --git a/kresources/scalix/shared/resourcescalixbase.h b/kresources/scalix/shared/resourcescalixbase.h
index e402e427..82c6e471 100644
--- a/kresources/scalix/shared/resourcescalixbase.h
+++ b/kresources/scalix/shared/resourcescalixbase.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
diff --git a/kresources/scalix/shared/scalixbase.h b/kresources/scalix/shared/scalixbase.h
index 2db064f7..b837ab03 100644
--- a/kresources/scalix/shared/scalixbase.h
+++ b/kresources/scalix/shared/scalixbase.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -53,8 +53,8 @@ class ScalixBase {
public:
struct Email {
public:
- Email( const TQString& name = TQString::null,
- const TQString& email = TQString::null )
+ Email( const TQString& name = TQString(),
+ const TQString& email = TQString() )
: displayName( name ), smtpAddress( email )
{
}
@@ -65,7 +65,7 @@ public:
enum Sensitivity { Public = 0, Private = 1, Confidential = 2 };
- explicit ScalixBase( const TQString& timezone = TQString::null );
+ explicit ScalixBase( const TQString& timezone = TQString() );
virtual ~ScalixBase();
// Return a string identifying this type
@@ -93,9 +93,9 @@ public:
virtual bool hasPilotSyncId() const;
virtual unsigned long pilotSyncId() const;
- virtual void setPilotSyncStatus( int status );
- virtual bool hasPilotSyncStatus() const;
- virtual int pilotSyncStatus() const;
+ virtual void setPilotSynctqStatus( int status );
+ virtual bool hasPilotSynctqStatus() const;
+ virtual int pilotSynctqStatus() const;
// String - Date conversion methods
static TQString dateTimeToString( const TQDateTime& time );
@@ -115,7 +115,7 @@ public:
bool load( const TQString& xml );
bool load( TQFile& xml );
- // Load this QDomDocument
+ // Load this TQDomDocument
virtual bool loadXML( const TQDomDocument& xml ) = 0;
// Serialize this object to an XML string
@@ -166,9 +166,9 @@ protected:
TQString mTimeZoneId;
// KPilot synchronization stuff
- bool mHasPilotSyncId, mHasPilotSyncStatus;
+ bool mHasPilotSyncId, mHasPilotSynctqStatus;
unsigned long mPilotSyncId;
- int mPilotSyncStatus;
+ int mPilotSynctqStatus;
};
}
diff --git a/kresources/scalix/shared/subresource.cpp b/kresources/scalix/shared/subresource.cpp
index 02c9e40f..bd3fdd8a 100644
--- a/kresources/scalix/shared/subresource.cpp
+++ b/kresources/scalix/shared/subresource.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
diff --git a/kresources/scalix/shared/subresource.h b/kresources/scalix/shared/subresource.h
index d7c575da..3fcb6b03 100644
--- a/kresources/scalix/shared/subresource.h
+++ b/kresources/scalix/shared/subresource.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -46,7 +46,7 @@ namespace Scalix {
*/
class SubResource {
public:
- // This is just for QMap
+ // This is just for TQMap
SubResource() {}
SubResource( bool active, bool writable, const TQString& label,
@@ -86,7 +86,7 @@ typedef TQMap<TQString, SubResource> ResourceMap;
*/
class StorageReference {
public:
- // Just for QMap
+ // Just for TQMap
StorageReference() {}
StorageReference( const TQString& resource, TQ_UINT32 sernum );
diff --git a/kresources/scalix/shared/scalixbase.cpp b/kresources/scalix/shared/scalixbase.cpp
index e9a5ab8c..64400e4f 100644
--- a/kresources/scalix/shared/scalixbase.cpp
+++ b/kresources/scalix/shared/scalixbase.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -45,7 +45,7 @@ ScalixBase::ScalixBase( const TQString& tz )
: mCreationDate( TQDateTime::tqcurrentDateTime() ),
mLastModified( TQDateTime::tqcurrentDateTime() ),
mSensitivity( Public ), mTimeZoneId( tz ),
- mHasPilotSyncId( false ), mHasPilotSyncStatus( false )
+ mHasPilotSyncId( false ), mHasPilotSynctqStatus( false )
{
}
@@ -56,7 +56,7 @@ ScalixBase::~ScalixBase()
void ScalixBase::setFields( const KCal::Incidence* incidence )
{
// So far unhandled KCal::IncidenceBase fields:
// mPilotID, mSyncStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );
@@ -231,20 +231,20 @@ unsigned long ScalixBase::pilotSyncId() const
return mPilotSyncId;
}
-void ScalixBase::setPilotSyncStatus( int status )
+void ScalixBase::setPilotSynctqStatus( int status )
{
- mHasPilotSyncStatus = true;
- mPilotSyncStatus = status;
+ mHasPilotSynctqStatus = true;
+ mPilotSynctqStatus = status;
}
-bool ScalixBase::hasPilotSyncStatus() const
+bool ScalixBase::hasPilotSynctqStatus() const
{
- return mHasPilotSyncStatus;
+ return mHasPilotSynctqStatus;
}
-int ScalixBase::pilotSyncStatus() const
+int ScalixBase::pilotSynctqStatus() const
{
- return mPilotSyncStatus;
+ return mPilotSynctqStatus;
}
bool ScalixBase::loadEmailAttribute( TQDomElement& element, Email& email )
@@ -300,7 +300,7 @@ bool ScalixBase::loadAttribute( TQDomElement& element )
else if ( tagName == "pilot-sync-id" )
setPilotSyncId( element.text().toULong() );
else if ( tagName == "pilot-sync-status" )
- setPilotSyncStatus( element.text().toInt() );
+ setPilotSynctqStatus( element.text().toInt() );
else
return false;
@@ -320,8 +320,8 @@ bool ScalixBase::saveAttributes( TQDomElement& element ) const
writeString( element, "sensitivity", sensitivityToString( sensitivity() ) );
if ( hasPilotSyncId() )
writeString( element, "pilot-sync-id", TQString::number( pilotSyncId() ) );
- if ( hasPilotSyncStatus() )
- writeString( element, "pilot-sync-status", TQString::number( pilotSyncStatus() ) );
+ if ( hasPilotSynctqStatus() )
+ writeString( element, "pilot-sync-status", TQString::number( pilotSynctqStatus() ) );
return true;
}
@@ -372,12 +372,12 @@ TQDomDocument ScalixBase::domTree()
TQString ScalixBase::dateTimeToString( const TQDateTime& time )
{
- return time.toString( Qt::ISODate ) + 'Z';
+ return time.toString( TQt::ISODate ) + 'Z';
}
TQString ScalixBase::dateToString( const TQDate& date )
{
- return date.toString( Qt::ISODate );
+ return date.toString( TQt::ISODate );
}
TQDateTime ScalixBase::stringToDateTime( const TQString& _date )
@@ -385,12 +385,12 @@ TQDateTime ScalixBase::stringToDateTime( const TQString& _date )
TQString date( _date );
if ( date.endsWith( "Z" ) )
date.truncate( date.length() - 1 );
- return TQDateTime::fromString( date, Qt::ISODate );
+ return TQDateTime::fromString( date, TQt::ISODate );
}
TQDate ScalixBase::stringToDate( const TQString& date )
{
- return TQDate::fromString( date, Qt::ISODate );
+ return TQDate::fromString( date, TQt::ISODate );
}
TQString ScalixBase::sensitivityToString( Sensitivity s )
@@ -56,7 +56,7 @@ ScalixBase::~ScalixBase()
{
// So far unhandled KCal::IncidenceBase fields:
- // mPilotID, mSyncStatus, mFloats
+ // mPilotID, mSynctqStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );